pub trait ThreadLocalFallibleTryDropStrategy: DynFallibleTryDropStrategy + 'static { }Expand description
A trait which signifies a try drop strategy which can be used in a thread local scenario. Must be dynamically dispatched and must live as long as the program does.